@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pipes-http
 version: 1.0.2
-id: pipes-http-1.0.2-6097bd429130c2729dfb14657b2bb810
-key: pipes_7S0ONFuPIPK74ElYBkImtB
+id: pipes-http-1.0.2-00ca7612e725b2352178919679bd2479
+key: pipes_GZDZK2tNwDZ6uUmEwoKkFE
 license: BSD3
 copyright: 2014 Gabriel Gonzalez
 maintainer: Gabriel439@gmail.com
@@ -19,13 +19,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pipes-http-1.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pipes-http-1.0.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/pipes-http-1.0.2
-hs-libraries: HSpipes-http-1.0.2-7S0ONFuPIPK74ElYBkImtB
+hs-libraries: HSpipes-http-1.0.2-GZDZK2tNwDZ6uUmEwoKkFE
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
-    http-client-tls-0.2.3-dfa8d8f591f2399ab0bdf7c21e1d9977
-    pipes-4.1.8-48aeb04c3fec70e47e537a12d228def1
+    http-client-0.4.28-3a5d04f7eb5922409c889a37b339ae0f
+    http-client-tls-0.2.4-ad0e9a866e1feb2eac114d565c18f6c6
+    pipes-4.1.9-8b262b53761b077dec55bfc46d38ba0f
 haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
 haddock-html: /usr/share/doc/haskell-pipes-http/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
